@@ -30,6 +30,8 @@
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
+from PyKDE4.kdeui import *
+import ppdippstr
 
 """
 These classes are used in the Job Options tab of the printer config dialogue
@@ -126,41 +128,50 @@ class OptionAlwaysShown(OptionInterface):
         """Set the original value of the option and the supported choices.
         The special value None for original_value resets the option to the
         system default."""
+        self.widget.blockSignals(True)
         if (supported != None and
             self.use_supported):
-            if (type(self.widget) == QComboBox and
+            if (isinstance(self.widget, QComboBox) and
                 self.ipp_type == str):
                 self.widget.clear()
-                if type(supported) == list:
-                    for each in supported:
-                        self.widget.addItem(unicode(each))
-                else:
-                    self.widget.addItem(self.combobox_dict[supported])
-            elif (type(self.widget) == QComboBox and
+                translations = ppdippstr.job_options.get (self.name)
+                if translations:
+                    self.combobox_map = []
+                    self.combobox_dict = dict()
+                    i = 0
+
+                for each in supported:
+                    if translations:
+                        self.combobox_map.append (each)
+                        text = translations.get (each)
+                        self.combobox_dict[each] = text
+                        i += 1
+                    else:
+                        text = each
+
+                    self.widget.addItem(unicode(each))
+            elif (isinstance(self.widget, QComboBox) and
                   self.ipp_type == int and
                   self.combobox_map != None):
                 self.widget.clear()
-                if type(supported) == list:
-                    for each in supported:
-                        self.widget.addItem(unicode(each))
-                else:
-                    self.widget.addItem(supported)
+                for each in supported:
+                    self.widget.addItem(unicode(self.combobox_dict[each]))
+
         if original_value != None:
             self.original_value = self.ipp_type (original_value)
             self.set_widget_value (self.original_value)
-            if original_value != self.get_widget_value():
-                self.button.setEnabled(True)
+            self.button.setEnabled (True)
         else:
             self.original_value = None
             self.set_widget_value (self.system_default)
-            self.button.setEnabled(False)
+            self.button.setEnabled (False)
         self.state = self.STATE_UNCHANGED
+        self.widget.blockSignals(False)
 
     def set_widget_value(self, ipp_value):
-        t = type(self.widget)
-        if t == QSpinBox:
+        if isinstance(self.widget, QSpinBox):
             return self.widget.setValue(ipp_value)
-        elif t == QComboBox:
+        elif isinstance(self.widget, QComboBox):
             if self.ipp_type == str and self.combobox_map == None:
                 index = self.widget.findText(ipp_value)
                 if index != -1:
@@ -172,14 +183,13 @@ class OptionAlwaysShown(OptionInterface):
                 else:
                     index = ipp_value
                 return self.widget.setCurrentIndex(index)
-        elif t == QCheckBox:
+        elif isinstance(self.widget, QCheckBox):
             return self.widget.setChecked(ipp_value)
         else:
             return NotImplemented
 
     def get_widget_value(self):
-        t = type(self.widget)
-        if t == QSpinBox:
+        if isinstance(self.widget, QSpinBox):
             # Ideally we would use self.widget.get_value() here, but
             # it doesn't work if the value has been typed in and then
             # the Apply button immediately clicked.  To handle this,
@@ -191,13 +201,13 @@ class OptionAlwaysShown(OptionInterface):
             except ValueError:
                 # Can't convert result of get_text() to ipp_type.
                 return self.ipp_type (self.widget.value ())
-        elif t == QComboBox:
+        elif isinstance(self.widget, QComboBox):
             if self.combobox_map:
                 return self.combobox_map[self.widget.currentIndex()]
             if self.ipp_type == str:
                 return self.widget.currentText()
             return self.ipp_type (unicode(self.widget.currentText()))
-        elif t == QCheckBox:
+        elif isinstance(self.widget, QCheckBox):
             return self.ipp_type (self.widget.isChecked())
 
         return NotImplemented
@@ -398,7 +408,7 @@ class OptionText(Option):
         Option.__init__(self, name, value, supported, on_change)
 
         self.selector = QLineEdit()
-        self.selector.setText(value)
+        self.selector.setText(unicode(value))
         self.selector.connect(self.selector, SIGNAL("textChanged(QString)"), self.changed)
 
     def get_current_value(self):
